@@ -25,7 +25,7 @@ public class SQLTable extends JTable {
         t_model = _model;
     }
     public SQLTableModel getTableModel(){
-        return t_model;
+        return (SQLTableModel) getModel();
     }
     
     public void showColumns(int columns){
