@@ -15,7 +15,6 @@ import pgclibrary.utilities.*;
 public class TablePanel extends JTabbedPane {
     Table table_object = null;
     
-    JTextField oid = new JTextField(20);
     JTextField name = new JTextField(20);
     JTextField owner = new JTextField(20);
     JTextField pages = new JTextField(20);
@@ -70,7 +69,6 @@ public class TablePanel extends JTabbedPane {
     }
         
     private void insertDefaultTab() {
-        oid.setEditable(false);
         name.setEditable(false);
         owner.setEditable(false);
         pages.setEditable(false);
@@ -90,7 +88,6 @@ public class TablePanel extends JTabbedPane {
         
         JPanel general_panel = new JPanel();
         general_panel.setLayout(new BoxLayout(general_panel, BoxLayout.Y_AXIS));
-        general_panel.add(SUtilities.getHorPanel("Table ID :", oid));
         general_panel.add(SUtilities.getHorPanel("Table Name :", name));
         general_panel.add(SUtilities.getHorPanel("Description :", dpane));
         general_panel.add(SUtilities.getHorPanel("Table Owner :", owner));
@@ -101,7 +98,6 @@ public class TablePanel extends JTabbedPane {
     }
     
     private void refreshDefaultPanel(){
-        oid.setText(String.valueOf(table_object.getOID()));
         name.setText(table_object.getName());
         owner.setText(table_object.getCreator().getName());
         pages.setText(String.valueOf(table_object.getNumberOfPages()));
