@@ -14,7 +14,6 @@ import pgclibrary.utilities.*;
 public class ViewPanel extends JTabbedPane {
     View view_object = null;
     
-    JTextField oid = new JTextField(20);
     JTextField name = new JTextField(20);
     JTextField owner = new JTextField(20);
     JTextArea description = new JTextArea(3, 20);
@@ -63,7 +62,6 @@ public class ViewPanel extends JTabbedPane {
     }
         
     private void insertDefaultTab() {
-        oid.setEditable(false);
         name.setEditable(false);
         owner.setEditable(false);
         description.setEditable(false);
@@ -83,7 +81,6 @@ public class ViewPanel extends JTabbedPane {
         
         JPanel general_panel = new JPanel();
         general_panel.setLayout(new BoxLayout(general_panel, BoxLayout.Y_AXIS));
-        general_panel.add(SUtilities.getHorPanel("View ID :", oid));
         general_panel.add(SUtilities.getHorPanel("View Name :", name));
         general_panel.add(SUtilities.getHorPanel("View Owner :", owner));
         general_panel.add(SUtilities.getHorPanel("Description :", dpane));
@@ -93,7 +90,6 @@ public class ViewPanel extends JTabbedPane {
     }
     
     private void refreshDefaultPanel(){
-        oid.setText(String.valueOf(view_object.getOID()));
         name.setText(view_object.getName());
         owner.setText(view_object.getCreator().getName());
         sql.setText(view_object.getInsertSQL());
