@@ -23,7 +23,7 @@ import java.sql.*;
  */
 public class PrincipalFrame extends JFrame {
     private PrincipalFrameListener listener = null;
-    private Database current_database = new Database(null, 0);
+    private Database current_database = new Database(null);
     private  SystemProps systemProperties = new SystemProps();
     
     private PrincipalFrameToolbar toolbar = null;
@@ -67,7 +67,7 @@ public class PrincipalFrame extends JFrame {
     }
     
     public void disconnect(){
-        current_database = new Database(null, 0);
+        current_database = new Database(null);
         refreshData();
         refreshValidation();
     }
