@@ -29,6 +29,8 @@ public class MainConnection extends Object implements Serializable {
     private Connection connection = null;   // java.sql.Connection utilizado
     private Statement statement = null;
     
+    private DatabaseQuerys databaseQG = null;  // Database query generator
+    
     private Vector error_text = new Vector();
     private long error_code = 0;
     
@@ -66,30 +68,6 @@ public class MainConnection extends Object implements Serializable {
         }
     }
     
-    /**
-     *This process allows the current user to change his password
-     */
-    
-    public boolean changePassword(String _newPassword){
-        boolean retorno = false;
-        error_text = new Vector();
-        error_code = 0;
-        
-        if((_newPassword != null) && (_newPassword.length() > 0)){
-            Properties props = new Properties();
-            props.put("user",userName);
-            props.put("password",password);
-            props.put("OCINewPassword", _newPassword);
-            retorno = connect(props);
-            if(retorno){
-                password = _newPassword;
-            }
-        } else {
-            error_text.add("Ths password is incorrect or the database is not accesible.");
-        }
-        return retorno;
-    }
-    
     /* Makes the connection and manage the posible errors.
      **/
     private boolean connect(Properties props){
@@ -126,7 +104,6 @@ public class MainConnection extends Object implements Serializable {
         return retorno;
     }
     
-    
     /**
      * Inits the predeterminated driver and url connection
      * the a defined user
@@ -304,23 +281,6 @@ public class MainConnection extends Object implements Serializable {
         return getConnection().prepareStatement(sql, ResultSet.TYPE_SCROLL_INSENSITIVE, ResultSet.CONCUR_READ_ONLY);
     }
     
-    /**
-     * MAkes a navegable statement
-     * An Connection.prepareStatement() abstraction
-     *
-     * @return PreparedStatement.
-     * @param sql Query to run
-     * @param tipo ResultSet type
-     * @param concur Concurrency type
-     * @throws SQLException Connection throws
-     */
-    public PreparedStatement prepareStatement(String sql, int tipo, int concur) throws SQLException{
-        if (!isConnected()){
-            throw new SQLException("The connection is not initialized");
-        }
-        return getConnection().prepareStatement(sql, tipo, concur);
-    }
-    
     /**
      * Closes the databse connection
      * It must be called before MainConnection release
@@ -413,6 +373,14 @@ public class MainConnection extends Object implements Serializable {
         return retorno;
     }
     
+    public DatabaseQuerys getQueryGenerator(){
+        if(databaseQG == null){
+            databaseQG = DatabaseQuerys.getDefaultQueryGenerator(this);
+        }
+        return databaseQG;
+    }
+    
+    
     static {
         Locale.setDefault(Locale.US);
     }
