@@ -95,19 +95,16 @@ public class Database extends DBObject {
         if(validate()){
             try{
                 initialize();
-                
-                PreparedStatement prep = getConnection().prepareStatement("SELECT * FROM pg_database WHERE DATNAME=?");
-                prep.setString(1, _name);
-                ResultSet rs = prep.executeQuery();
-                if(rs.next()){
-                    setName(rs.getString("DATNAME"));
-                    setDBA(rs.getLong("DATDBA"));
-                    setTemplate(rs.getBoolean("datistemplate"));
-                    setAllowConnections(rs.getBoolean("datallowconn"));
+                ResultSet rs = getConnection().getQueryGenerator().getDatabases(_name);
+                if ((rs != null) && (rs.next())){
+                    setName(rs.getString("DATABASE_NAME"));
+                    setDBA(rs.getString("DATABASE_DBA"));
+                    setTemplate(rs.getBoolean("DATABASE_TEMPLATE"));
+                    setAllowConnections(rs.getBoolean("DATABASE_ALLOWCONN"));
                     retorno = true;
                 }
                 rs.close();
-                prep.close();
+                rs.getStatement().close();
             } catch (SQLException e){
                 e.printStackTrace();
             }
@@ -139,7 +136,7 @@ public class Database extends DBObject {
     private void setDBA(User _user){
         setCreator(_user);
     }
-    private void setDBA(long _user){
+    private void setDBA(String _user){
         setCreator(new User(this, _user));
     }
     public User getDBA(){
