@@ -93,31 +93,21 @@ public class Sequence extends DBObject {
         boolean retorno = false;
         try{
             initialize();
-            PreparedStatement prep = getConnection().prepareStatement("SELECT * FROM PG_CLASS WHERE RELNAME=?");
-            prep.setString(1, _name);
-            ResultSet rs = prep.executeQuery();
-            if(rs.next()){
-                setName(rs.getString("RELNAME"));
-                setCreator(new User(this, rs.getLong("RELOWNER")));
-                
-                PreparedStatement prep1 = getConnection().prepareStatement("SELECT * FROM " + getName());
-                ResultSet rs1 = prep1.executeQuery();
-                if(rs1.next()){
-                    setLastValue(rs1.getLong("LAST_VALUE"));
-                    setIncrementBy(rs1.getLong("INCREMENT_BY"));
-                    setMaxValue(rs1.getLong("MAX_VALUE"));
-                    setMinValue(rs1.getLong("MIN_VALUE"));
-                    setCacheValue(rs1.getLong("CACHE_VALUE"));
-                    setCycled(rs1.getBoolean("IS_CYCLED"));
-                    setCalled(rs1.getBoolean("IS_CALLED"));
-                    retorno = true;
-                }
-                rs1.close();
-                prep1.close();
+            ResultSet rs = getConnection().getQueryGenerator().getSequence(_name);
+            if((rs != null) && rs.next()){
+                setName(rs.getString("SEQUENCE_NAME"));
+                setCreator(new User(this, rs.getString("SEQUENCE_OWNER")));
+                setLastValue(rs.getLong("LAST_VALUE"));
+                setIncrementBy(rs.getLong("INCREMENT_BY"));
+                setMaxValue(rs.getLong("MAX_VALUE"));
+                setMinValue(rs.getLong("MIN_VALUE"));
+                setCacheValue(rs.getLong("CACHE_VALUE"));
+                setCycled(rs.getBoolean("IS_CYCLED"));
+                setCalled(rs.getBoolean("IS_CALLED"));
+                retorno = true;
             }
-            
             rs.close();
-            prep.close();
+            rs.getStatement().close();
         } catch (SQLException e){
             e.printStackTrace();
             initialize();
@@ -197,35 +187,15 @@ public class Sequence extends DBObject {
     private String getCommentSQL(){
         String retorno = new String();
         if(getDescription().length() > 0){
-            retorno = "COMMENT ON SEQUENCE " + getName() 
-                        + " IS '" + getDescription() + "'; \n";
+            retorno = "COMMENT ON SEQUENCE " + getName()
+            + " IS '" + getDescription() + "'; \n";
         }
         return retorno;
     }
     
     public String getDescription(){
         if(description == null){
-            try{
-                PreparedStatement prep;
-                
-                if(getConnection().getDatabaseVersion() < 7.2){
-                    prep = getConnection().prepareStatement("select obj_description(oid) as DESCRIPTION from pg_class where RELNAME=? ");
-                } else {
-                    prep = getConnection().prepareStatement("select obj_description(oid, relname) as DESCRIPTION from pg_class where RELNAME=? ");
-                }
-                prep.setString(1, getName());
-                
-                ResultSet rs = prep.executeQuery();
-                if(rs.next()){
-                    setDescription(rs.getString("DESCRIPTION"));
-                } else {
-                    setDescription(new String());
-                }
-                rs.close();
-                prep.close();
-            } catch (SQLException e){
-                e.printStackTrace();
-            }
+            description = getConnection().getQueryGenerator().getTableDescription(getName());
         }
         return description;
     }
