@@ -129,17 +129,16 @@ public class Table extends DBObject {
         boolean retorno = false;
         try{
             initialize();
-            PreparedStatement prep = getConnection().prepareStatement("SELECT * FROM PG_CLASS WHERE RELNAME=?");
-            prep.setString(1, _name);
-            ResultSet rs = prep.executeQuery();
-            if(rs.next()){
-                setName(rs.getString("RELNAME"));
-                setNumberOfPages(rs.getLong("RELPAGES"));
-                setCreator(new User(this, rs.getLong("RELOWNER")));
+            
+            ResultSet rs = getConnection().getQueryGenerator().getTable(_name);
+            if((rs != null) && rs.next()){
+                setName(rs.getString("TABLE_NAME"));
+                setNumberOfPages(rs.getLong("TABLE_PAGES"));
+                setCreator(new User(this, rs.getString("TABLE_OWNER")));
                 retorno = true;
             }
             rs.close();
-            prep.close();
+            rs.getStatement().close();
         } catch (SQLException e){
             e.printStackTrace();
         }
@@ -227,18 +226,15 @@ public class Table extends DBObject {
     public Vector getColumns(){
         if(columns == null){
             columns = new Vector();
+            
             try{
-                PreparedStatement prep = getConnection().prepareStatement("select pg_attribute.*"
-                + "  from pg_attribute, pg_class "
-                + "  where pg_attribute.attrelid = pg_class.oid and attnum> 0 and  relname= ? ORDER BY attnum");
-                prep.setString(1, getName());
-                ResultSet rs = prep.executeQuery();
-                while(rs.next()){
-                    TableColumn tc = new TableColumn(this, rs.getString("ATTNAME"));
+                ResultSet rs = getConnection().getQueryGenerator().getColumnNames(getName());
+                while((rs != null) && rs.next()){
+                    TableColumn tc = new TableColumn(this, rs.getString("COLUMN_NAME"));
                     columns.add(tc);
                 }
                 rs.close();
-                prep.close();
+                rs.getStatement().close();
             } catch (SQLException e){
                 e.printStackTrace();
             }
@@ -261,17 +257,13 @@ public class Table extends DBObject {
         if(index == null){
             index = new Vector();
             try{
-                PreparedStatement prep = getConnection().prepareStatement("select a.RELNAME "
-                + " from pg_index, pg_class a, pg_class b where a.oid = pg_index.indexrelid "
-                + " and b.oid = pg_index.indrelid and b.relname =? ");
-                prep.setString(1, getName());
-                ResultSet rs = prep.executeQuery();
-                while(rs.next()){
-                    TableIndex ti = new TableIndex(this, rs.getString("RELNAME"));
+                ResultSet rs = getConnection().getQueryGenerator().getIndexNames(getName());
+                while((rs != null) && rs.next()){
+                    TableIndex ti = new TableIndex(this, rs.getString("INDEX_NAME"));
                     index.add(ti);
                 }
                 rs.close();
-                prep.close();
+                rs.getStatement().close();
             } catch (SQLException e){
                 e.printStackTrace();
             }
@@ -414,27 +406,7 @@ public class Table extends DBObject {
     }
     public String getDescription(){
         if(description == null){
-            try{
-                PreparedStatement prep;
-                
-                if(getConnection().getDatabaseVersion() < 7.2){
-                    prep = getConnection().prepareStatement("select obj_description(oid) as DESCRIPTION from pg_class where RELNAME=? ");
-                } else {
-                    prep = getConnection().prepareStatement("select obj_description(oid, relname) as DESCRIPTION from pg_class where RELNAME=? ");
-                }
-                prep.setString(1, getName());
-                
-                ResultSet rs = prep.executeQuery();
-                if(rs.next()){
-                    setDescription(rs.getString("DESCRIPTION"));
-                } else {
-                    setDescription(new String());
-                }
-                rs.close();
-                prep.close();
-            } catch (SQLException e){
-                e.printStackTrace();
-            }
+            description = getConnection().getQueryGenerator().getTableDescription(getName()); 
         }
         return description;
     }
