@@ -18,7 +18,7 @@ public class TableColumn extends DBObject {
     private int size = 0;
     private boolean allow_nulls = false;
     private AttributeType column_type = null;
-    private String default_value = null;
+    private String default_value = new String();
     private String description = null;
     
     public TableColumn(DBObject owner, String _name) {
@@ -79,24 +79,18 @@ public class TableColumn extends DBObject {
         try{
             initialize();
             
-            PreparedStatement prep = getConnection().prepareStatement("select pg_attribute.*, "
-            + " case when pg_attribute.attlen > 0 then pg_attribute.attlen "
-            + "                 else pg_attribute.atttypmod-4 end as colsize "
-            + " from pg_class, pg_attribute "
-            + " where pg_attribute.attrelid=pg_class.oid AND pg_class.relname=? and pg_attribute.ATTNAME=? ");
-            prep.setString(1, getOwner().getName());
-            prep.setString(2, _name);
-            ResultSet rs = prep.executeQuery();
+            ResultSet rs = getConnection().getQueryGenerator().getTableColumn(getOwner().getName(), _name);
             if((rs != null) && (rs.next())){
-                setName(rs.getString("ATTNAME"));
-                setColumnNumber(rs.getInt("attnum"));
-                setSize(rs.getInt("COLSIZE"));
-                setAllowNulls(!rs.getBoolean("attnotnull"));
-                setColumnType(AttributeType.searchObject(rs.getLong("atttypid")));
+                setName(rs.getString("COLUMN_NAME"));
+                setColumnNumber(rs.getInt("COLUMN_NUMBER"));
+                setSize(rs.getInt("COLUMN_SIZE"));
+                setAllowNulls(!rs.getBoolean("COLUMN_NOTNULL"));
+                setColumnType(AttributeType.searchObject(rs.getString("TYPE_NAME")));
+                setDefaultValue(rs.getString("DEFAULT_VALUE"));
                 retorno = true;
             }
             rs.close();
-            prep.close();
+            rs.getStatement().close();
         } catch (SQLException e){
             e.printStackTrace();
         }
@@ -109,37 +103,19 @@ public class TableColumn extends DBObject {
         size = 0;
         allow_nulls = false;
         column_type = null;
-        default_value = null;
+        default_value = new String();
         description = null;
     }
     
     // ---------SET AND GET-------------
     private void setDefaultValue(String _value){
-         default_value = _value;
+        if(_value != null){
+            default_value = _value;
+        } else {
+            default_value = new String();
+        }
     }
     public String getDefaultValue(){
-        if (default_value == null){
-            default_value = new String();
-            try{
-                PreparedStatement preps = getConnection().prepareStatement("select  "
-                + " adsrc as DEFAULT "
-                + " from pg_attrdef, pg_class, pg_attribute "
-                + " WHERE pg_attribute.attrelid = pg_attrdef.adrelid "
-                + "  and pg_attribute.attnum = pg_attrdef.adnum "
-                + "  and pg_attribute.attrelid = pg_class.oid "
-                + "  and pg_class.relname= ? AND pg_attribute.ATTNAME=? ");
-                preps.setString(1, getOwner().getName());
-                preps.setString(2, getName());
-                ResultSet rs = preps.executeQuery();
-                if((rs != null)  && rs.next()){
-                    default_value = rs.getString("DEFAULT");
-                }
-                rs.close();
-                preps.close();
-            } catch (SQLException e){
-                e.printStackTrace();
-            }
-        }
         return default_value;
     }
     
@@ -177,28 +153,7 @@ public class TableColumn extends DBObject {
     
     public String getDescription(){
         if(description == null){
-            try{
-                PreparedStatement prep;
-                
-                if(getConnection().getDatabaseVersion() < 7.2){
-                    prep = getConnection().prepareStatement("select obj_description(pg_attribute.oid) as DESCRIPTION from pg_attribute, pg_class where pg_class.oid = pg_attribute.attrelid and RELNAME=? AND ATTNAME=? ");
-                } else {
-                    prep = getConnection().prepareStatement("select col_description(attrelid, ATTNUM) as DESCRIPTION from pg_attribute, pg_class where pg_class.oid = pg_attribute.attrelid and RELNAME=? AND ATTNAME=? ");
-                }
-                prep.setString(1, getOwner().getName());
-                prep.setString(2, getName());
-                
-                ResultSet rs = prep.executeQuery();
-                if(rs.next()){
-                    setDescription(rs.getString("DESCRIPTION"));
-                } else {
-                    setDescription(new String());
-                }
-                rs.close();
-                prep.close();
-            } catch (SQLException e){
-                e.printStackTrace();
-            }
+            description = getConnection().getQueryGenerator().getColumnDescription(getOwner().getName(), getName());
         }
         return description;
     }
