@@ -83,24 +83,17 @@ public class TableIndex extends DBObject {
     public boolean search(String _name) {
         boolean retorno = false;
         try{
-            PreparedStatement prep = getConnection().prepareStatement("select "
-            + " RELNAME as INDNAME, "
-            + " INDISCLUSTERED, INDHASKEYTYPE, "
-            + " INDISUNIQUE, INDISPRIMARY "
-            + " from pg_index, pg_class "
-            + " where pg_class.oid = indexrelid and RELNAME = ? ");
-            prep.setString(1, _name);
-            ResultSet rs = prep.executeQuery();
+            ResultSet rs = getConnection().getQueryGenerator().getIndex(_name);
             if((rs != null) && (rs.next())){
-                setName(rs.getString("INDNAME"));
-                setClustered(rs.getBoolean("INDISCLUSTERED"));
-                setHasKeyType(rs.getBoolean("INDHASKEYTYPE"));
-                setUnique(rs.getBoolean("INDISUNIQUE"));
-                setPrimary(rs.getBoolean("INDISPRIMARY"));
+                setName(rs.getString("INDEX_NAME"));
+                setClustered(rs.getBoolean("INDEX_CLUSTER"));
+                setHasKeyType(rs.getBoolean("INDEX_HASH"));
+                setUnique(rs.getBoolean("INEDEX_UNIQUE"));
+                setPrimary(rs.getBoolean("INDEX_PRIMARY"));
                 retorno = true;
             }
             rs.close();
-            prep.close();
+            rs.getStatement().close();
         } catch (SQLException e){
             e.printStackTrace();
         }
@@ -123,19 +116,13 @@ public class TableIndex extends DBObject {
         if(columns == null){
             columns = new Vector();
             try{
-                PreparedStatement prep = getConnection().prepareStatement(
-                "select pg_attribute.*  from pg_attribute, pg_class "
-                + " where pg_attribute.attrelid=pg_class.OID AND ATTNUM > 0 "
-                + "     and pg_class.relname=? ");
-                prep.setString(1, getName());
-                
-                ResultSet rs = prep.executeQuery();
-                while(rs.next()){
-                    TableColumn tc = new TableColumn(this, rs.getString("ATTNAME")); 
+                ResultSet rs = getConnection().getQueryGenerator().getColumnNames(getName());
+                while((rs != null) && rs.next()){
+                    TableColumn tc = new TableColumn(this, rs.getString("COLUMN_NAME")); 
                     columns.add(tc);
                 }
                 rs.close();
-                prep.close();
+                rs.getStatement().close();
             } catch (SQLException e){
                 e.printStackTrace();
             }
@@ -195,27 +182,7 @@ public class TableIndex extends DBObject {
     
     public String getDescription(){
         if(description == null){
-            try{
-                PreparedStatement prep;
-                
-                if(getConnection().getDatabaseVersion() < 7.2){
-                    prep = getConnection().prepareStatement("select obj_description(oid) as DESCRIPTION from pg_class where RELNAME=? ");
-                } else {
-                    prep = getConnection().prepareStatement("select obj_description(oid, relname) as DESCRIPTION from pg_class where RELNAME=? ");
-                }
-                prep.setString(1, getName());
-                
-                ResultSet rs = prep.executeQuery();
-                if(rs.next()){
-                    setDescription(rs.getString("DESCRIPTION"));
-                } else {
-                    setDescription(new String());
-                }
-                rs.close();
-                prep.close();
-            } catch (SQLException e){
-                e.printStackTrace();
-            }
+            description = getConnection().getQueryGenerator().getTableDescription(getName());
         }
         return description;
     }
