@@ -63,26 +63,15 @@ public class View extends DBObject {
         boolean retorno = false;
         try{
             initialize();
-            PreparedStatement prep = getConnection().prepareStatement("SELECT * FROM PG_CLASS WHERE RELNAME=?");
-            prep.setString(1, _name);
-            ResultSet rs = prep.executeQuery();
-            if(rs.next()){
-                setName(rs.getString("RELNAME"));
-                setCreator(new User(this, rs.getLong("RELOWNER")));
-                
-                PreparedStatement prep1 = getConnection().prepareStatement("SELECT * FROM PG_VIEWS WHERE VIEWNAME=?");
-                prep1.setString(1, getName());
-                ResultSet rs1 = prep1.executeQuery();
-                if(rs1.next()){
-                    setDefinition(rs1.getString("DEFINITION"));
-                    retorno = true;
-                }
-                rs1.close();
-                prep1.close();
+            ResultSet rs = getConnection().getQueryGenerator().getView(_name);
+            if((rs != null) && rs.next()){
+                setName(rs.getString("VIEW_NAME"));
+                setCreator(new User(this, rs.getString("VIEW_OWNER")));
+                setDefinition(rs.getString("VIEW_DEFINITION"));
                 retorno = true;
             }
             rs.close();
-            prep.close();
+            rs.getStatement().close();
         } catch (SQLException e){
             e.printStackTrace();
         }
@@ -157,16 +146,12 @@ public class View extends DBObject {
         if(columns == null){
             columns = new Vector();
             try{
-                PreparedStatement prep = getConnection().prepareStatement("select pg_attribute.* "
-                    + " from pg_attribute, pg_class where pg_attribute.ATTRELID = pg_class.oid "
-                    + " and pg_class.relname=? and attnum > 0 order by attnum");
-                prep.setString(1, getName());
-                ResultSet rs = prep.executeQuery();
-                while(rs.next()){
-                    columns.add(new TableColumn(this, rs.getString("ATTNAME")));
+                ResultSet rs = getConnection().getQueryGenerator().getColumnNames(getName());
+                while((rs != null) && rs.next()){
+                    columns.add(new TableColumn(this, rs.getString("COLUMN_NAME")));
                 }
                 rs.close();
-                prep.close();
+                rs.getStatement().close();
             } catch (SQLException e){
                 e.printStackTrace();
             }
@@ -184,27 +169,7 @@ public class View extends DBObject {
     }
     public String getDescription(){
         if(description == null){
-            try{
-                PreparedStatement prep;
-                
-                if(getConnection().getDatabaseVersion() < 7.2){
-                    prep = getConnection().prepareStatement("select obj_description(oid) as DESCRIPTION from pg_class where RELNAME=? ");
-                } else {
-                    prep = getConnection().prepareStatement("select obj_description(oid, relname) as DESCRIPTION from pg_class where RELNAME=? ");
-                }
-                prep.setString(1, getName());
-                
-                ResultSet rs = prep.executeQuery();
-                if(rs.next()){
-                    setDescription(rs.getString("DESCRIPTION"));
-                } else {
-                    setDescription(new String());
-                }
-                rs.close();
-                prep.close();
-            } catch (SQLException e){
-                e.printStackTrace();
-            }
+            description = getConnection().getQueryGenerator().getTableDescription(getName());
         }
         return description;
     }
