@@ -22,13 +22,12 @@ public class DatabaseList extends TreeInfo {
     public void rebuildProperties() {
         removeAllProperties();
         try{
-            PreparedStatement prep = getConnection().prepareStatement("SELECT DATNAME FROM pg_database ORDER BY DATNAME");
-            ResultSet rs = prep.executeQuery();
-            while(rs.next()){
-                addProperty(new Element(this, new Database(getConnection(), rs.getString("DATNAME"))));
+            ResultSet rs = getConnection().getQueryGenerator().getDatabaseNames();
+            while((rs != null) && rs.next()){
+                addProperty(new Element(this, new Database(getConnection(), rs.getString("DATABASE_NAME"))));
             }
             rs.close();
-            prep.close();
+            rs.getStatement().close();
         } catch (SQLException e){}
     }
     
