@@ -31,8 +31,8 @@ public class Element extends TreeInfo {
     }
     
     // ------SET AND GET--------
-    public long getOID() {
-        return source.getOID();
+    public Object getOID() {
+        return source.getName();
     }
     public DBObject getSource(){
         return source;
