@@ -29,13 +29,12 @@ public class GroupList extends TreeInfo {
     public void rebuildProperties() {
         removeAllProperties();
         try{
-            PreparedStatement prep = getConnection().prepareStatement("SELECT GRONAME FROM PG_GROUP");
-            ResultSet rs = prep.executeQuery();
-            while(rs.next()){
-                addProperty(new Element(this, new Group(getDatabase(), rs.getString("GRONAME"))));
+            ResultSet rs = getConnection().getQueryGenerator().getGroupNames();
+            while((rs != null) && rs.next()){
+                addProperty(new Element(this, new Group(getDatabase(), rs.getString("GROUP_NAME"))));
             }
             rs.close();
-            prep.close();
+            rs.getStatement().close();
         } catch (SQLException e){
         }
     }
