@@ -25,13 +25,12 @@ public class SequenceList extends TreeInfo {
     public void rebuildProperties() {
         removeAllProperties();
         try{
-            PreparedStatement prep = getConnection().prepareStatement("SELECT RELNAME FROM PG_CLASS WHERE RELKIND='S' ORDER BY RELNAME");
-            ResultSet rs = prep.executeQuery();
+            ResultSet rs = getConnection().getQueryGenerator().getSequenceNames();
             while(rs.next()){
-                addProperty(new Element(this, new Sequence(getDatabase(), rs.getString("RELNAME"))));
+                addProperty(new Element(this, new Sequence(getDatabase(), rs.getString("SEQUENCE_NAME"))));
             }
             rs.close();
-            prep.close();
+            rs.getStatement().close();
         } catch (SQLException e){}
     }
     
