@@ -29,13 +29,12 @@ public class TableList extends TreeInfo {
     public void rebuildProperties() {
         removeAllProperties();
         try{
-            PreparedStatement prep = getConnection().prepareStatement("SELECT RELNAME FROM PG_CLASS WHERE RELKIND='r' ORDER BY RELNAME");
-            ResultSet rs = prep.executeQuery();
-            while(rs.next()){
-                addProperty(new Element(this, new Table(getDatabase(), rs.getString("RELNAME"))));
+            ResultSet rs = getConnection().getQueryGenerator().getTableNames();
+            while((rs != null) && rs.next()){
+                addProperty(new Element(this, new Table(getDatabase(), rs.getString("TABLE_NAME"))));
             }
             rs.close();
-            prep.close();
+            rs.getStatement().close();
         } catch (SQLException e){
         }
     }
