@@ -28,7 +28,7 @@ public abstract class TreeInfo extends java.lang.Object {
     }
     
     public abstract void rebuildProperties();
-    public abstract long getOID();
+    public abstract Object getOID();
     
     public boolean validate(){
         errors = new Vector();
