@@ -25,13 +25,12 @@ public class UserList extends TreeInfo {
     public void rebuildProperties() {
         removeAllProperties();
         try{
-            PreparedStatement prep = getConnection().prepareStatement("SELECT * FROM PG_USER ORDER BY USENAME");
-            ResultSet rs = prep.executeQuery();
+            ResultSet rs = getConnection().getQueryGenerator().getUserNames();
             while(rs.next()){
-                addProperty(new Element(this, new User(getDatabase(), rs.getLong("USESYSID"))));
+                addProperty(new Element(this, new User(getDatabase(), rs.getString("USER_NAME"))));
             }
             rs.close();
-            prep.close();
+            rs.getStatement().close();
         } catch (SQLException e){
         }
     }
