@@ -25,13 +25,12 @@ public class ViewList extends TreeInfo {
     public void rebuildProperties() {
         removeAllProperties();
         try{
-            PreparedStatement prep = getConnection().prepareStatement("SELECT RELNAME FROM PG_CLASS WHERE RELKIND='v' ORDER BY RELNAME");
-            ResultSet rs = prep.executeQuery();
-            while(rs.next()){
-                addProperty(new Element(this, new View(getDatabase(), rs.getString("RELNAME")))); 
+            ResultSet rs =  getConnection().getQueryGenerator().getViewNames();
+            while((rs != null) && rs.next()){
+                addProperty(new Element(this, new View(getDatabase(), rs.getString("VIEW_NAME")))); 
             }
             rs.close();
-            prep.close();
+            rs.getStatement().close();
         } catch (SQLException e){
         }
     }
